==> aws-cdk.aws-elasticloadbalancingv2-1.119.0.tar.gz: package/lib/nlb/network-listener.d.ts <==
import { Duration, IResource } from '@aws-cdk/core';
import { Construct } from 'constructs';
import { BaseListener, BaseListenerLookupOptions } from '../shared/base-listener';
import { HealthCheck } from '../shared/base-target-group';
import { Protocol, SslPolicy } from '../shared/enums';
import { IListenerCertificate } from '../shared/listener-certificate';
import { NetworkListenerAction } from './network-listener-action';
import { INetworkLoadBalancer } from './network-load-balancer';
import { INetworkLoadBalancerTarget, INetworkTargetGroup, NetworkTargetGroup } from './network-target-group';
/**
 * Basic properties for a Network Listener.
 *
 * @stability stable
 */
export interface BaseNetworkListenerProps {
    /**
     * The port on which the listener listens for requests.
     *
     * @stability stable
     */
    readonly port: number;
    /**
     * Default target groups to load balance to.
     *
     * All target groups will be load balanced to with equal weight and without
     * stickiness. For a more complex configuration than that, use
     * either `defaultAction` or `addAction()`.
     *
     * Cannot be specified together with `defaultAction`.
     *
     * @default - None.
     * @stability stable
     */
    readonly defaultTargetGroups?: INetworkTargetGroup[];
    /**
     * Default action to take for requests to this listener.
     *
     * This allows full control of the default Action of the load balancer,
     * including weighted forwarding. See the `NetworkListenerAction` class for
     * all options.
     *
     * Cannot be specified together with `defaultTargetGroups`.
     *
     * @default - None.
     * @stability stable
     */
    readonly defaultAction?: NetworkListenerAction;
    /**
     * Protocol for listener, expects TCP, TLS, UDP, or TCP_UDP.
     *
     * @default - TLS if certificates are provided. TCP otherwise.
     * @stability stable
     */
    readonly protocol?: Protocol;
    /**
     * Certificate list of ACM cert ARNs.
     *
     * @default - No certificates.
     * @stability stable
     */
    readonly certificates?: IListenerCertificate[];
    /**
     * SSL Policy.
     *
     * @default - Current predefined security policy.
     * @stability stable
     */
    readonly sslPolicy?: SslPolicy;
}
/**
 * (deprecated) Properties for adding a certificate to a listener.
 *
 * This interface exists for backwards compatibility.
 *
 * @deprecated Use IListenerCertificate instead
 */
export interface INetworkListenerCertificateProps extends IListenerCertificate {
}
/**
 * Properties for a Network Listener attached to a Load Balancer.
 *
 * @stability stable
 */
export interface NetworkListenerProps extends BaseNetworkListenerProps {
    /**
     * The load balancer to attach this listener to.
     *
     * @stability stable
     */
    readonly loadBalancer: INetworkLoadBalancer;
}
/**
 * Options for looking up a network listener.
 *
 * @stability stable
 */
export interface NetworkListenerLookupOptions extends BaseListenerLookupOptions {
    /**
     * Protocol of the listener port.
     *
     * @default - listener is not filtered by protocol
     * @stability stable
     */
    readonly listenerProtocol?: Protocol;
}
/**
 * Define a Network Listener.
 *
 * @stability stable
 * @resource AWS::ElasticLoadBalancingV2::Listener
 */
export declare class NetworkListener extends BaseListener implements INetworkListener {
    /**
     * Looks up a network listener.
     *
     * @stability stable
     */
    static fromLookup(scope: Construct, id: string, options: NetworkListenerLookupOptions): INetworkListener;
    /**
     * Import an existing listener.
     *
     * @stability stable
     */
    static fromNetworkListenerArn(scope: Construct, id: string, networkListenerArn: string): INetworkListener;
    /**
     * The load balancer this listener is attached to.
     *
     * @stability stable
     */
    readonly loadBalancer: INetworkLoadBalancer;
    /**
     * the protocol of the listener
     */
    private readonly protocol;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: NetworkListenerProps);
    /**
     * Load balance incoming requests to the given target groups.
     *
     * All target groups will be load balanced to with equal weight and without
     * stickiness. For a more complex configuration than that, use `addAction()`.
     *
     * @stability stable
     */
    addTargetGroups(_id: string, ...targetGroups: INetworkTargetGroup[]): void;
    /**
     * Perform the given Action on incoming requests.
     *
     * This allows full control of the default Action of the load balancer,
     * including weighted forwarding. See the `NetworkListenerAction` class for
     * all options.
     *
     * @stability stable
     */
    addAction(_id: string, props: AddNetworkActionProps): void;
    /**
     * Load balance incoming requests to the given load balancing targets.
     *
     * This method implicitly creates a NetworkTargetGroup for the targets
     * involved, and a 'forward' action to route traffic to the given TargetGroup.
     *
     * If you want more control over the precise setup, create the TargetGroup
     * and use `addAction` yourself.
     *
     * It's possible to add conditions to the targets added in this way. At least
     * one set of targets must be added without conditions.
     *
     * @returns The newly created target group
     * @stability stable
     */
    addTargets(id: string, props: AddNetworkTargetsProps): NetworkTargetGroup;
    /**
     * Wrapper for _setDefaultAction which does a type-safe bind
     */
    private setDefaultAction;
}
/**
 * Properties to reference an existing listener.
 *
 * @stability stable
 */
export interface INetworkListener extends IResource {
    /**
     * ARN of the listener.
     *
     * @stability stable
     * @attribute true
     */
    readonly listenerArn: string;
}
/**
 * Properties for adding a new action to a listener.
 *
 * @stability stable
 */
export interface AddNetworkActionProps {
    /**
     * Action to perform.
     *
     * @stability stable
     */
    readonly action: NetworkListenerAction;
}
/**
 * Properties for adding new network targets to a listener.
 *
 * @stability stable
 */
export interface AddNetworkTargetsProps {
    /**
     * The port on which the listener listens for requests.
     *
     * @default Determined from protocol if known
     * @stability stable
     */
    readonly port: number;
    /**
     * Protocol for target group, expects TCP, TLS, UDP, or TCP_UDP.
     *
     * @default - inherits the protocol of the listener
     * @stability stable
     */
    readonly protocol?: Protocol;
    /**
     * The targets to add to this target group.
     *
     * Can be `Instance`, `IPAddress`, or any self-registering load balancing
     * target. If you use either `Instance` or `IPAddress` as targets, all
     * target must be of the same type.
     *
     * @stability stable
     */
    readonly targets?: INetworkLoadBalancerTarget[];
    /**
     * The name of the target group.
     *
     * This name must be unique per region per account, can have a maximum of
     * 32 characters, must contain only alphanumeric characters or hyphens, and
     * must not begin or end with a hyphen.
     *
     * @default Automatically generated
     * @stability stable
     */
    readonly targetGroupName?: string;
    /**
     * The amount of time for Elastic Load Balancing to wait before deregistering a target.
     *
     * The range is 0-3600 seconds.
     *
     * @default Duration.minutes(5)
     * @stability stable
     */
    readonly deregistrationDelay?: Duration;
    /**
     * Indicates whether Proxy Protocol version 2 is enabled.
     *
     * @default false
     * @stability stable
     */
    readonly proxyProtocolV2?: boolean;
    /**
     * Indicates whether client IP preservation is enabled.
     *
     * @default false if the target group type is IP address and the
     * target group protocol is TCP or TLS. Otherwise, true.
     * @stability stable
     */
    readonly preserveClientIp?: boolean;
    /**
     * Health check configuration.
     *
     * @default No health check
     * @stability stable
     */
    readonly healthCheck?: HealthCheck;
}

==> aws-cdk.aws-elasticloadbalancingv2-1.125.0.tar.gz: package/lib/nlb/network-listener.d.ts <==
import { Duration, IResource } from '@aws-cdk/core';
import { Construct } from 'constructs';
import { BaseListener, BaseListenerLookupOptions } from '../shared/base-listener';
import { HealthCheck } from '../shared/base-target-group';
import { AlpnPolicy, Protocol, SslPolicy } from '../shared/enums';
import { IListenerCertificate } from '../shared/listener-certificate';
import { NetworkListenerAction } from './network-listener-action';
import { INetworkLoadBalancer } from './network-load-balancer';
import { INetworkLoadBalancerTarget, INetworkTargetGroup, NetworkTargetGroup } from './network-target-group';
/**
 * Basic properties for a Network Listener.
 *
 * @stability stable
 */
export interface BaseNetworkListenerProps {
    /**
     * The port on which the listener listens for requests.
     *
     * @stability stable
     */
    readonly port: number;
    /**
     * Default target groups to load balance to.
     *
     * All target groups will be load balanced to with equal weight and without
     * stickiness. For a more complex configuration than that, use
     * either `defaultAction` or `addAction()`.
     *
     * Cannot be specified together with `defaultAction`.
     *
     * @default - None.
     * @stability stable
     */
    readonly defaultTargetGroups?: INetworkTargetGroup[];
    /**
     * Default action to take for requests to this listener.
     *
     * This allows full control of the default Action of the load balancer,
     * including weighted forwarding. See the `NetworkListenerAction` class for
     * all options.
     *
     * Cannot be specified together with `defaultTargetGroups`.
     *
     * @default - None.
     * @stability stable
     */
    readonly defaultAction?: NetworkListenerAction;
    /**
     * Protocol for listener, expects TCP, TLS, UDP, or TCP_UDP.
     *
     * @default - TLS if certificates are provided. TCP otherwise.
     * @stability stable
     */
    readonly protocol?: Protocol;
    /**
     * Certificate list of ACM cert ARNs.
     *
     * @default - No certificates.
     * @stability stable
     */
    readonly certificates?: IListenerCertificate[];
    /**
     * SSL Policy.
     *
     * @default - Current predefined security policy.
     * @stability stable
     */
    readonly sslPolicy?: SslPolicy;
    /**
     * Application-Layer Protocol Negotiation (ALPN) is a TLS extension that is sent on the initial TLS handshake hello messages.
     *
     * ALPN enables the application layer to negotiate which protocols should be used over a secure connection, such as HTTP/1 and HTTP/2.
     *
     * Can only be specified together with Protocol TLS.
     *
     * @default - None
     * @stability stable
     */
    readonly alpnPolicy?: AlpnPolicy;
}
/**
 * (deprecated) Properties for adding a certificate to a listener.
 *
 * This interface exists for backwards compatibility.
 *
 * @deprecated Use IListenerCertificate instead
 */
export interface INetworkListenerCertificateProps extends IListenerCertificate {
}
/**
 * Properties for a Network Listener attached to a Load Balancer.
 *
 * @stability stable
 */
export interface NetworkListenerProps extends BaseNetworkListenerProps {
    /**
     * The load balancer to attach this listener to.
     *
     * @stability stable
     */
    readonly loadBalancer: INetworkLoadBalancer;
}
/**
 * Options for looking up a network listener.
 *
 * @stability stable
 */
export interface NetworkListenerLookupOptions extends BaseListenerLookupOptions {
    /**
     * Protocol of the listener port.
     *
     * @default - listener is not filtered by protocol
     * @stability stable
     */
    readonly listenerProtocol?: Protocol;
}
/**
 * Define a Network Listener.
 *
 * @stability stable
 * @resource AWS::ElasticLoadBalancingV2::Listener
 */
export declare class NetworkListener extends BaseListener implements INetworkListener {
    /**
     * Looks up a network listener.
     *
     * @stability stable
     */
    static fromLookup(scope: Construct, id: string, options: NetworkListenerLookupOptions): INetworkListener;
    /**
     * Import an existing listener.
     *
     * @stability stable
     */
    static fromNetworkListenerArn(scope: Construct, id: string, networkListenerArn: string): INetworkListener;
    /**
     * The load balancer this listener is attached to.
     *
     * @stability stable
     */
    readonly loadBalancer: INetworkLoadBalancer;
    /**
     * the protocol of the listener
     */
    private readonly protocol;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: NetworkListenerProps);
    /**
     * Load balance incoming requests to the given target groups.
     *
     * All target groups will be load balanced to with equal weight and without
     * stickiness. For a more complex configuration than that, use `addAction()`.
     *
     * @stability stable
     */
    addTargetGroups(_id: string, ...targetGroups: INetworkTargetGroup[]): void;
    /**
     * Perform the given Action on incoming requests.
     *
     * This allows full control of the default Action of the load balancer,
     * including weighted forwarding. See the `NetworkListenerAction` class for
     * all options.
     *
     * @stability stable
     */
    addAction(_id: string, props: AddNetworkActionProps): void;
    /**
     * Load balance incoming requests to the given load balancing targets.
     *
     * This method implicitly creates a NetworkTargetGroup for the targets
     * involved, and a 'forward' action to route traffic to the given TargetGroup.
     *
     * If you want more control over the precise setup, create the TargetGroup
     * and use `addAction` yourself.
     *
     * It's possible to add conditions to the targets added in this way. At least
     * one set of targets must be added without conditions.
     *
     * @returns The newly created target group
     * @stability stable
     */
    addTargets(id: string, props: AddNetworkTargetsProps): NetworkTargetGroup;
    /**
     * Wrapper for _setDefaultAction which does a type-safe bind
     */
    private setDefaultAction;
}
/**
 * Properties to reference an existing listener.
 *
 * @stability stable
 */
export interface INetworkListener extends IResource {
    /**
     * ARN of the listener.
     *
     * @stability stable
     * @attribute true
     */
    readonly listenerArn: string;
}
/**
 * Properties for adding a new action to a listener.
 *
 * @stability stable
 */
export interface AddNetworkActionProps {
    /**
     * Action to perform.
     *
     * @stability stable
     */
    readonly action: NetworkListenerAction;
}
/**
 * Properties for adding new network targets to a listener.
 *
 * @stability stable
 */
export interface AddNetworkTargetsProps {
    /**
     * The port on which the listener listens for requests.
     *
     * @default Determined from protocol if known
     * @stability stable
     */
    readonly port: number;
    /**
     * Protocol for target group, expects TCP, TLS, UDP, or TCP_UDP.
     *
     * @default - inherits the protocol of the listener
     * @stability stable
     */
    readonly protocol?: Protocol;
    /**
     * The targets to add to this target group.
     *
     * Can be `Instance`, `IPAddress`, or any self-registering load balancing
     * target. If you use either `Instance` or `IPAddress` as targets, all
     * target must be of the same type.
     *
     * @stability stable
     */
    readonly targets?: INetworkLoadBalancerTarget[];
    /**
     * The name of the target group.
     *
     * This name must be unique per region per account, can have a maximum of
     * 32 characters, must contain only alphanumeric characters or hyphens, and
     * must not begin or end with a hyphen.
     *
     * @default Automatically generated
     * @stability stable
     */
    readonly targetGroupName?: string;
    /**
     * The amount of time for Elastic Load Balancing to wait before deregistering a target.
     *
     * The range is 0-3600 seconds.
     *
     * @default Duration.minutes(5)
     * @stability stable
     */
    readonly deregistrationDelay?: Duration;
    /**
     * Indicates whether Proxy Protocol version 2 is enabled.
     *
     * @default false
     * @stability stable
     */
    readonly proxyProtocolV2?: boolean;
    /**
     * Indicates whether client IP preservation is enabled.
     *
     * @default false if the target group type is IP address and the
     * target group protocol is TCP or TLS. Otherwise, true.
     * @stability stable
     */
    readonly preserveClientIp?: boolean;
    /**
     * Health check configuration.
     *
     * @default No health check
     * @stability stable
     */
    readonly healthCheck?: HealthCheck;
}
